@@ -1013,13 +1013,14 @@ class Abstract_Wallet(PrintError):
         outputs = copy.deepcopy(tx.outputs())
         for txin in inputs:
             txin['signatures'] = [None] * len(txin['signatures'])
+            self.add_input_info(txin)
         for i, o in enumerate(outputs):
             otype, address, value = o
             if self.is_mine(address) and value >= delta:
                 outputs[i] = otype, address, value - delta
                 break
         else:
-            raise BaseException("cannot bump fee")
+            raise BaseException("cannot bump fee: could not find a change output")
         new_tx = Transaction.from_io(inputs, outputs)
         return new_tx
 
@@ -1040,6 +1041,7 @@ class Abstract_Wallet(PrintError):
         for k in self.get_keystores():
             if k.can_sign(tx):
                 return True
+        return False
 
     def get_input_tx(self, tx_hash):
         # First look up an input transaction in the wallet where it
@@ -1061,11 +1063,17 @@ class Abstract_Wallet(PrintError):
             txin['prev_tx'] = self.get_input_tx(tx_hash)
 
         # add output info for hw wallets
-        tx.output_info = []
-        for i, txout in enumerate(tx.outputs()):
+        info = {}
+        xpubs = self.get_master_public_keys()
+        for txout in tx.outputs():
             _type, addr, amount = txout
-            change, address_index = self.get_address_index(addr) if self.is_change(addr) else (None, None)
-            tx.output_info.append((change, address_index))
+            if self.is_change(addr):
+                index = self.get_address_index(addr)
+                pubkeys = self.get_public_keys(addr)
+                # sort xpubs using the order of pubkeys
+                sorted_pubkeys, sorted_xpubs = zip(*sorted(zip(pubkeys, xpubs)))
+                info[addr] = index, sorted_xpubs, self.m if isinstance(self, Multisig_Wallet) else None
+        tx.output_info = info
 
         # sign
         for k in self.get_keystores():
@@ -1299,7 +1307,7 @@ class Imported_Wallet(Abstract_Wallet):
         return False
 
     def get_master_public_keys(self):
-        return {}
+        return []
 
     def is_beyond_limit(self, address, is_change):
         return False
@@ -1374,7 +1382,6 @@ class P2PK_Wallet(Abstract_Wallet):
             pubkey = self.get_public_key(address)
             assert pubkey is not None
             x_pubkey = pubkey
-
         txin['x_pubkeys'] = [x_pubkey]
         txin['pubkeys'] = [pubkey]
         txin['signatures'] = [None]
@@ -1414,9 +1421,6 @@ class Deterministic_Wallet(Abstract_Wallet):
     def add_seed(self, seed, pw):
         self.keystore.add_seed(seed, pw)
 
-    def get_mnemonic(self, password):
-        return self.keystore.get_mnemonic(password)
-
     def change_gap_limit(self, value):
         '''This method is not called in the code, it is kept for console use'''
         if value >= self.gap_limit:
@@ -1508,7 +1512,7 @@ class Deterministic_Wallet(Abstract_Wallet):
         return True
 
     def get_master_public_keys(self):
-        return {'x':self.get_master_public_key()}
+        return [self.get_master_public_key()]
 
     def get_fingerprint(self):
         return self.get_master_public_key()
@@ -1601,7 +1605,7 @@ class Multisig_Wallet(Deterministic_Wallet):
         return address
 
     def new_pubkeys(self, c, i):
-        return [k.derive_pubkey(c, i) for k in self.keystores.values()]
+        return [k.derive_pubkey(c, i) for k in self.get_keystores()]
 
     def load_keystore(self):
         self.keystores = {}
@@ -1618,7 +1622,7 @@ class Multisig_Wallet(Deterministic_Wallet):
         return self.keystores.get('x1/')
 
     def get_keystores(self):
-        return self.keystores.values()
+        return [self.keystores[i] for i in sorted(self.keystores.keys())]
 
     def update_password(self, old_pw, new_pw):
         for name, keystore in self.keystores.items():
@@ -1642,7 +1646,7 @@ class Multisig_Wallet(Deterministic_Wallet):
         return self.keystore.get_master_public_key()
 
     def get_master_public_keys(self):
-        return dict(map(lambda x: (x[0], x[1].get_master_public_key()), self.keystores.items()))
+        return [k.get_master_public_key() for k in self.get_keystores()]
 
     def get_fingerprint(self):
         return ''.join(sorted(self.get_master_public_keys()))
