@@ -73,7 +73,7 @@ class NetworkChoiceLayout(object):
             else:
                 status += "\n" + _("Disconnected from server")
         else:
-            status = _("Please choose a server.") + "\n" + _("Select 'Cancel' if you are offline.")
+            status = _("Please choose a server.") + "\n" + _("Press 'Next' if you are offline.")
 
         vbox = QVBoxLayout()
         hbox = QHBoxLayout()
