@@ -77,11 +77,10 @@ class TxDialog(QDialog, MessageBoxMixin):
         self.tx_hash_e.addButton(":icons/qrcode.png", qr_show, _("Show as QR code"))
         self.tx_hash_e.setReadOnly(True)
         vbox.addWidget(self.tx_hash_e)
-        self.status_label = QLabel()
-        vbox.addWidget(self.status_label)
-
         self.tx_desc = QLabel()
         vbox.addWidget(self.tx_desc)
+        self.status_label = QLabel()
+        vbox.addWidget(self.status_label)
         self.date_label = QLabel()
         vbox.addWidget(self.date_label)
         self.amount_label = QLabel()
@@ -176,39 +175,22 @@ class TxDialog(QDialog, MessageBoxMixin):
 
 
     def update(self):
-        is_relevant, is_mine, v, fee = self.wallet.get_wallet_delta(self.tx)
-        tx_hash = self.tx.hash()
         desc = self.desc
-        time_str = None
-        self.broadcast_button.hide()
+        base_unit = self.main_window.base_unit()
+        format_amount = self.main_window.format_amount
+        tx_hash, status, label, can_broadcast, can_rbf, amount, fee, height, conf, timestamp, exp_n = self.wallet.get_tx_info(self.tx)
 
-        if self.tx.is_complete():
-            status = _("Signed")
-
-            if tx_hash in self.wallet.transactions.keys():
-                desc = self.wallet.get_label(tx_hash)
-                conf, timestamp = self.wallet.get_confirmations(tx_hash)
-                if timestamp:
-                    time_str = datetime.datetime.fromtimestamp(timestamp).isoformat(' ')[:-3]
-                else:
-                    time_str = _('Pending')
-                status = _("%d confirmations")%conf
-            else:
-                self.broadcast_button.show()
-                # cannot broadcast when offline
-                if self.main_window.network is None:
-                    self.broadcast_button.setEnabled(False)
+        if can_broadcast:
+            self.broadcast_button.show()
         else:
-            s, r = self.tx.signature_count()
-            status = _("Unsigned") if s == 0 else _('Partially signed') + ' (%d/%d)'%(s,r)
-            tx_hash = _('Unknown');
+            self.broadcast_button.hide()
 
         if self.wallet.can_sign(self.tx):
             self.sign_button.show()
         else:
             self.sign_button.hide()
 
-        self.tx_hash_e.setText(tx_hash)
+        self.tx_hash_e.setText(tx_hash or _('Unknown'))
         if desc is None:
             self.tx_desc.hide()
         else:
@@ -216,42 +198,32 @@ class TxDialog(QDialog, MessageBoxMixin):
             self.tx_desc.show()
         self.status_label.setText(_('Status:') + ' ' + status)
 
-        if time_str is not None:
+        if timestamp:
+            time_str = datetime.datetime.fromtimestamp(timestamp).isoformat(' ')[:-3]
             self.date_label.setText(_("Date: %s")%time_str)
             self.date_label.show()
+        elif exp_n:
+            text = '%d blocks'%(exp_n) if exp_n > 0 else _('unknown (low fee)')
+            self.date_label.setText(_('Expected confirmation time') + ': ' + text)
+            self.date_label.show()
         else:
             self.date_label.hide()
-
-        # if we are not synchronized, we cannot tell
-        if not self.wallet.up_to_date:
-            return
-
-        base_unit = self.main_window.base_unit()
-        format_amount = self.main_window.format_amount
-
-        if is_relevant:
-            if is_mine:
-                if fee is not None:
-                    self.amount_label.setText(_("Amount sent:")+' %s'% format_amount(-v+fee) + ' ' + base_unit)
-                    self.fee_label.setText(_("Transaction fee")+': %s'% format_amount(-fee) + ' ' + base_unit)
-                else:
-                    self.amount_label.setText(_("Amount sent:")+' %s'% format_amount(-v) + ' ' + base_unit)
-                    self.fee_label.setText(_("Transaction fee")+': '+ _("unknown"))
-            else:
-                self.amount_label.setText(_("Amount received:")+' %s'% format_amount(v) + ' ' + base_unit)
+        if amount is None:
+            amount_str = _("Transaction unrelated to your wallet")
+        elif amount > 0:
+            amount_str = _("Amount received:") + ' %s'% format_amount(amount) + ' ' + base_unit
         else:
-            self.amount_label.setText(_("Transaction unrelated to your wallet"))
-
+            amount_str = _("Amount sent:") + ' %s'% format_amount(-amount) + ' ' + base_unit
+        fee_str = _("Transaction fee") + ': %s'% (format_amount(fee) + ' ' + base_unit if fee is not None else _('unknown'))
+        self.amount_label.setText(amount_str)
+        self.fee_label.setText(fee_str)
         run_hook('transaction_dialog_update', self)
 
-
     def add_io(self, vbox):
-
         if self.tx.locktime > 0:
             vbox.addWidget(QLabel("LockTime: %d\n" % self.tx.locktime))
 
         vbox.addWidget(QLabel(_("Inputs") + ' (%d)'%len(self.tx.inputs())))
-
         ext = QTextCharFormat()
         rec = QTextCharFormat()
         rec.setBackground(QBrush(QColor("lightgreen")))
